@@ -1,6 +1,7 @@
-from .by_industry.birt import BIRTCollectionsByIndustry
-from .by_industry.sales import SalesCollectionsByIndustry
-from .by_industry.wage import WageCollectionsByIndustry
+from .by_sector.birt import BIRTCollectionsBySector
+from .by_sector.rtt import RTTCollectionsBySector
+from .by_sector.sales import SalesCollectionsBySector
+from .by_sector.wage import WageCollectionsBySector
 from .monthly.city_nontax import CityNonTaxCollections
 from .monthly.city_other_govts import CityOtherGovtsCollections
 from .monthly.city_tax import CityTaxCollections
